@@ -1,11 +1,15 @@
 from argostranslate.translate import ITranslation
 
+from argostranslatefiles.formats.opendocument.odt import Odt
 from argostranslatefiles.formats.openxml.docx import Docx
 from argostranslatefiles.formats.openxml.pptx import Pptx
+from argostranslatefiles.formats.txt import Txt
 
 
 def get_supported_formats():
     return [
+        Txt(),
+        Odt(),
         Docx(),
         Pptx()
     ]
